@@ -56,7 +56,7 @@
  * returns a new data structure (for association with a row)
  * filled with default values
  */
-static gpointer cid_row_new() {
+static gpointer cid_row_new(void) {
   struct cid_row_t *rowdata =
     (struct cid_row_t *) malloc(sizeof(struct cid_row_t));
   
@@ -94,7 +94,7 @@ static void cid_delete_response_cb(GtkWidget* widget, gint response_id,
                                    gpointer data)
 {
   session_t* session = (session_t*) data;
-  guint row = (guint) g_object_get_data(G_OBJECT(widget), "row");
+  guint row = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(widget), "row"));
   char* filename = (char*) g_object_get_data(G_OBJECT(widget), "filename");
   GtkWidget* checkbutton =
     (GtkWidget*) g_object_get_data(G_OBJECT(widget), "checkbutton");
@@ -154,7 +154,7 @@ static void cid_request_delete(GtkWidget *widget _U_, gpointer data,
   gtk_box_pack_start_defaults(GTK_BOX(vbox), checkbutton);
   gtk_widget_show(checkbutton);
 
-  g_object_set_data(G_OBJECT(dialog), "row", (gpointer) row);
+  g_object_set_data(G_OBJECT(dialog), "row", GUINT_TO_POINTER(row));
   g_object_set_data(G_OBJECT(dialog), "filename", (gpointer) filename);
   g_object_set_data(G_OBJECT(dialog), "checkbutton", (gpointer) checkbutton);
   g_signal_connect(dialog, "response", G_CALLBACK(cid_delete_response_cb),
@@ -173,7 +173,7 @@ static gint cid_key_cb(GtkWidget *widget, GdkEventKey *event, gpointer data) {
       /* portability: GtkCList.selection is private! */
       if (GTK_CLIST(((session_t *) data)->cid_list)->selection) {
         cid_request_delete(widget, data,
-	    (int)GTK_CLIST(((session_t *) data)->cid_list)->selection->data);
+	    GPOINTER_TO_INT(GTK_CLIST(((session_t *) data)->cid_list)->selection->data));
       }
       return TRUE; /* event handled */
     default:
@@ -293,7 +293,7 @@ static void cid_delete_rec_response_cb(GtkWidget* widget, gint response_id,
 
   if (response_id == GTK_RESPONSE_OK) {
     char* temp;
-    guint row = (guint) g_object_get_data(G_OBJECT(widget), "row");
+    guint row = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(widget), "row"));
     unlink(temp = cid_get_record_filename(session, row));
     free(temp);
     cid_row_mark_record(session, row);
@@ -313,7 +313,7 @@ static void cid_delete_rec(GtkWidget *widget _U_, gpointer data, guint row) {
   g_signal_connect(dialog, "response", G_CALLBACK(cid_delete_rec_response_cb),
                    session);
   gtk_window_set_modal(GTK_WINDOW(dialog), TRUE);
-  g_object_set_data(G_OBJECT(dialog), "row", (gpointer) row);
+  g_object_set_data(G_OBJECT(dialog), "row", GINT_TO_POINTER(row));
   gtk_widget_show(dialog);
 }
 
@@ -788,8 +788,8 @@ void cid_calls_merge(session_t *session) {
     if (fclose(f))
       fprintf(stderr, "Error closing %s.\n", calls_filename);
   } else { /* error on fopen() */
-    fprintf(stderr, "Warning: Couldn't open %s. Proceeding without it.\n",
-	    calls_filename);
+    fprintf(stderr,
+      "Warning: Couldn't open isdnlog calls logfile. Proceeding without it.\n");
   }
   free(line);
 }
