@@ -49,7 +49,8 @@
 #include "isdn.h"
 
 static char* calls_filenames[] =
-{ "/var/lib/isdn/calls", "/var/log/isdn/calls" };
+{ "/var/lib/isdn/calls", "/var/log/isdn/calls", "/var/log/isdn.log" };
+char* isdn_calls_filename_from_config = NULL;
 
 /*
  * locks (via lock file) and opens a (free) ttyI device
@@ -537,10 +538,19 @@ int isdn_set_full_duplex(int isdn_fd) {
  * returns the name of the calls file (originally just /var/lib/isdn/calls)
  * on error, returns NULL
  */
-char* isdn_get_calls_filename() {
+char* isdn_get_calls_filename(void) {
   unsigned int i;
   int fd;
-  
+
+  if (isdn_calls_filename_from_config &&
+      (fd = open(isdn_calls_filename_from_config, O_RDONLY)) != -1)
+  {
+    close(fd);
+    if (debug)
+      fprintf(stderr,
+	      "Using calls file from I4L config.\n");
+    return isdn_calls_filename_from_config;
+  }
   for (i = 0; i < sizeof(calls_filenames) / sizeof(char*); i++) {
     if ((fd = open(calls_filenames[i], O_RDONLY)) != -1) {
       close(fd);
