@@ -44,6 +44,11 @@
 #define DC4 0x14
 #define DLE 0x10
 
+#define ISDN_CONFIG_FILENAME "/home/ernie/isdn.conf"
+// XXX
+
+extern char* isdn_calls_filename_from_config;
+
 int open_isdn_device(char **isdn_device_name, char **isdn_lockfile_name);
 int init_isdn_device(int isdn_fd, struct termios *backup);
 int deinit_isdn_device(int isdn_fd, struct termios *backup);
@@ -59,5 +64,5 @@ int isdn_set_full_duplex(int isdn_fd);
 int tty_read(int fd, char *s, int timeout, char **got);
 int tty_write(int fd, char *s);
 int tty_clear(int fd);
-char* isdn_get_calls_filename();
+char* isdn_get_calls_filename(void);
 
